ContentDisposition

Struct ContentDisposition 

pub struct ContentDisposition {
    pub disposition: DispositionType,
    pub parameters: Vec<DispositionParam>,
}
A Content-Disposition header, (re)defined in RFC6266.

The Content-Disposition response header field is used to convey additional information about how to process the response payload, and also can be used to attach additional metadata, such as the filename to use when saving the response payload locally.

ABNF

content-disposition = "Content-Disposition" ":"
                      disposition-type *( ";" disposition-parm )

disposition-type    = "inline" | "attachment" | disp-ext-type
                      ; case-insensitive

disp-ext-type       = token

disposition-parm    = filename-parm | disp-ext-parm

filename-parm       = "filename" "=" value
                    | "filename*" "=" ext-value

disp-ext-parm       = token "=" value
                    | ext-token "=" ext-value

ext-token           = <the characters in token, followed by "*">

Fields

disposition: DispositionType

The disposition

parameters: Vec<DispositionParam>

Disposition parameters

Implementations

Source

impl ContentDisposition

pub fn is_inline(&self) -> bool

Returns true if type is Inline.

pub fn is_attachment(&self) -> bool

Returns true if type is Attachment.

pub fn is_form_data(&self) -> bool

Returns true if type is FormData.

pub fn is_ext(&self, disp_type: impl AsRef<str>) -> bool

Returns true if type is Ext and the disp_type matches.

pub fn get_name(&self) -> Option<&str>

Return the value of name if exists.

pub fn get_filename(&self) -> Option<&str>

Return the value of filename if exists.

pub fn get_filename_ext(&self) -> Option<&ExtendedValue>

Return the value of filename* if exists.

pub fn get_unknown(&self, name: impl AsRef<str>) -> Option<&str>

Return the value of the parameter which the name matches.

pub fn get_unknown_ext(&self, name: impl AsRef<str>) -> Option<&ExtendedValue>

Return the value of the extended parameter which the name matches.